==> codit_blocks-7.x-1.2.tar.gz: codit_blocks/README.md <==
Codit: Blocks
=============

CONTENTS OF THIS FILE
---------------------
 * Introduction
 * Features
 * Requirements
 * Installation
 * Configuration
 * Building Blocks
 * FAQ
 * Roadmap
 * Bonus Features
 * Maintainers

INTRODUCTION
------------
Codit: Blocks allows for creation of simple or complex blocks with custom
callback, access, and caching available for each block.

FEATURES
--------
 * Block Callback Function - Used for doing any heavy processing for the block.
   The code is contained in an anonymous function to reduce collision risk.
 * Access Function - Used to restrict access based on specific permission, role,
   user, field value or any combination thereof.
 * Caching - Caching of any Codit: Block's block can be done on a site-wide,
   per page, per path, per user, per role, per permission, per field value or
   any combination thereof.
 * Any block placed on a node or taxonomy term page has immediate access to that
   node object or taxonomy term.

REQUIREMENTS
------------
Dependency: Codit: Local
Dependency: Codit

INSTALLATION
------------
 * If Codit and Codit: Local have already been installed on your site, then this
   submodule is ready to be enabled.

CONFIGURATION
-------------
* No configuration is needed.  You simply create blocks and position them with
  Context, Panels, or the native block admin.

BUILDING BLOCKS
---------------
##Drush Steps (recommended):##
1. drush codit-blocks-add {blockname}  - This one command has created the block
   directory in codit_local/blocks/block_bin/ and created the template file and
   callback.inc.
2. Your new block is now be registered as a block.  You can move on down to
   'Your Block is Ready.'

Manual Steps
1. Codit: Blocks are created by copying the _a_sample_block directory inside
   codit_local/blocks/block_bin and naming it with the new block name (delta).
   example: cp -r codit_local/blocks/block_bin/_a_sample_block codit_local/blocks/block_bin/cool_block
2. Rename the tpl.php file in the directory to match the block name.
   example: rename _sample_block.tpl.php codit_blocks_cool_block.tpl.php
   Note: This tpl can also be copied *(not moved)* to the theme for overriding.
3. Open the tpl and alter extract($blockdata_a_sample_block); to be
   extract($blockdata_cool_block); then save the file.
4. Flush the cache and your new block 'cool block' will be registered with the
   the system. You can move on down to 'Your Block is Ready.'

**Your Block is Ready**
1. Place your block using Context, Panels or the native Drupal block admin.
   Whichever system you normally use, should be fine.
2. If your block requires any processing of php, this should be done in the
   _callback function located in  _callback.inc in the block directory.
   Anything $_callback() returns will be passed to the tpl (pass multiple items
   in an associative array).
6. (optional) Address any caching needed in $_cache_id() in _callback.inc
7. (optional) Address any access restrictions in $_access() in _callback.inc
8. Edit your tpl to format the output of the content of your block.


FAQ
---
Q: A block is misbehaving, how do I remove it temporarily?
 : A: You have several options.  The easiest is to add an underscore to the
   front of the directory name.  The underscore tells Codit: Blocks to ignore
   it. The other option would be to remove it from output in Context, Panels or
   the block admin.

Q: I created a block but it is not showing up.  What should I do?
 : A: There are several reasons why a block would not showing up:

  1. The name of the tpl file and the name of the block directory do not match.
    example: Directory name 'block_foo' needs to contain a tpl named
      'block_foo.tpl.php'
  2. The $_access() callback in _callback.inc is returning FALSE.
  3. The tpl is not outputting anything.
  4. The first time you loaded the block, nothing was output and that is now
     cached even though you changed the code.  Flush cache.
  5. It is not properly placed using Context, Panels, or block admin.

Q: I moved the tpl to the theme and the block is not showing up.  What is wrong?
 : A: The tpl for a block must reside in its directory inside
  codit_local/blocks/block_bin/  You can COPY the tpl to your theme to override
  it but do not MOVE it to your theme.

ROADMAP
-------
The following issues are slated for development.

 * Adding drush command that will create a block by copying the block sample
   directory and apply the name given.
   Ex: drush codit_block addblock myblockname

BONUS FEATURES
--------------
The following module is not required, but if you have it enabled it will
improve the experience:

 * Markdown - When the Markdown filter is enabled, display of the module help
   for any of the Codit modules and submodules will be rendered with markdown.

MAINTAINERS
-----------
* Steve Wirt (swirt) - https://drupal.org/user/138230

==> codit_blocks-7.x-1.3.tar.gz: codit_blocks/README.md <==
Codit: Blocks
=============

CONTENTS OF THIS FILE
---------------------
 * Introduction
 * Features
 * Requirements
 * Installation
 * Configuration
 * Building Blocks
 * FAQ
 * Roadmap
 * Bonus Features
 * Maintainers

INTRODUCTION
------------
Codit: Blocks allows for creation of simple or complex blocks with custom
callback, access, and caching available for each block.

FEATURES
--------
 * Block Callback Function - Used for doing any heavy processing for the block.
   The code is contained in an anonymous function to reduce collision risk.
 * Access Function - Used to restrict access based on specific permission, role,
   user, field value or any combination thereof.
 * Caching - Caching of any Codit: Block's block can be done on a site-wide,
   per page, per path, per user, per role, per permission, per field value or
   any combination thereof.
 * Any block placed on a node or taxonomy term page has immediate access to that
   node object or taxonomy term.

REQUIREMENTS
------------
Dependency: Codit: Local
Dependency: Codit

INSTALLATION
------------
 * If Codit and Codit: Local have already been installed on your site, then this
   submodule is ready to be enabled.

CONFIGURATION
-------------
* No configuration is needed.  You simply create blocks and position them with
  Context, Panels, or the native block admin.

BUILDING BLOCKS
---------------
##Drush Steps (recommended):##
1. drush codit-blocks-add {blockname}  - This one command has created the block
   directory in codit_local/blocks/block_bin/ and created the template file and
   callback.inc.
2. Your new block is now registered as a block.  You can move on down to
   'Your Block is Ready.'

Manual Steps
1. Codit: Blocks are created by copying the _a_sample_block directory inside
   codit_local/blocks/block_bin and naming it with the new block name (delta).
   example: cp -r codit_local/blocks/block_bin/_a_sample_block codit_local/blocks/block_bin/cool_block
   You must use underscores not hyphens and keep it shorter than 32 characters.
   Do not precede the name with an underscore, that is used to disable a block.
2. Rename the tpl.php file in the directory to match the block name.
   example: rename _sample_block.tpl.php codit_blocks_cool_block.tpl.php
   Note: This tpl can also be copied *(not moved)* to the theme for overriding.
3. Open the tpl and alter extract($blockdata_a_sample_block); to be
   extract($blockdata_cool_block); then save the file.
4. Flush the cache and your new block 'cool block' will be registered with the
   the system. You can move on down to 'Your Block is Ready.'

**Your Block is Ready**
1. Place your block using Context, Panels or the native Drupal block admin.
   Whichever system you normally use, should be fine.
2. If your block requires any processing of php, this should be done in the
   _callback function located in  _callback.inc in the block directory.
   Anything $_callback() returns will be passed to the tpl (pass multiple items
   in an associative array).
3. (optional) Address any caching needed in $_cache_id() in _callback.inc
4. (optional) Address any access restrictions in $_access() in _callback.inc
5. Edit your tpl to format the output of the content of your block.


Drush Commands
--------------
* drush codit-blocks-add {blockname} --enable=FALSE
  Creates the block directory, callback file and tpl in codit_local/blocks/bloc_bin.
  and flushes the block cache to register the new block.  The optional enabled
  flag can be set to false to start the block in the disabled state.
* drush codit-blocks-enable {blockname}
  If the block is currently disabled, it will enable it and flush the block
  cache to register it.
* drush codit-blocks-disable {blockname}
  Disables the block if it is enabled and flushes the block cache to de-register
  the block.
* drush codit-blocks-clear-cache
  Clears the block cache to register or de-register a block.
* drush codit-blocks-list
  Clears the block cache and lists the Codit: Blocks that are enabled.
* drush codit_blocks_local_init
  Sets up the blocks directory within Codit local if it does not exist.


FAQ
---
Q: A block is misbehaving, how do I remove it temporarily?
 : A: You have several options.  The easiest is to add an underscore to the
   front of the directory name.  The underscore tells Codit: Blocks to ignore
   it. The other option would be to remove it from output in Context, Panels or
   the block admin.

Q: I created a block but it is not showing up.  What should I do?
 : A: There are several reasons why a block would not showing up:

  1. The name of the tpl file and the name of the block directory do not match.
    example: Directory name 'block_foo' needs to contain a tpl named
      'block_foo.tpl.php'
  2. The $_access() callback in _callback.inc is returning FALSE.
  3. The tpl is not outputting anything.
  4. The first time you loaded the block, nothing was output and that is now
     cached even though you changed the code.  Flush cache.
  5. It is not properly placed using Context, Panels, or block admin.

Q: I moved the tpl to the theme and the block is not showing up.  What is wrong?
 : A: The tpl for a block must reside in its directory inside
  codit_local/blocks/block_bin/  You can COPY the tpl to your theme to override
  it, but do not MOVE it to your theme.

ROADMAP
-------
The following issues are slated for development.



BONUS FEATURES
--------------
The following module is not required, but if you have it enabled it will
improve the experience:

 * Markdown - When the Markdown filter is enabled, display of the module help
   for any of the Codit modules and submodules will be rendered with markdown.

MAINTAINERS
-----------
* Steve Wirt (swirt) - https://drupal.org/user/138230
